<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>Transfer aplikasi təsdiqləndikdən sonra uyğun UOS versiyasını avtomatik olaraq instalyasət</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Təsdiqlə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Ləğv et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>Aplikasiya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>Tavsiyə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>Transfer edilə bilər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>Uyğun deyil</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>Transfer etmək üçün aplikasiyaları seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>Sizə təqdim edilən təkliyələri yedekləmək üçün seçin</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>UOS məlumat transferi</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>UOS transfer aləti, fayllarını, şəxsi məlumatlarını və aplikasiyalarını UOS-a bir klikdə köçürməyə və sistemini mühəmlə tərəfindən əvəz etməyə kömək edir.</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>Yerli direktoriyaya çıxar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>Transfer yolu seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>Şəbəkə ilə əlaqə qurulamaz, şəbəkə əlaqəsini yoxlayın və ya yerli direktoriyaya çıxar seçin.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>Sıradakı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>Windows kompüterindən</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>Yedekləmə fayllarından yüklə</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>Transfer konfiqurasiyasını təsdiqləyin, UOS-a avtomatik olaraq tətbiq olunacaq.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Təsdiqlə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Ləğv et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>Tarayıcıya əlavə etmək</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>Tavsiyə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>Transfer edilə bilər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>Şəxsi ayarlar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>Kəsildi məlumatlar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>Transfer etmək üçün konfiqurasiyaları seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>Sizə təqdim edilən təkliyələri yedekləmək üçün seçin</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>Əlaqə qurulacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>Windows-da məlumat transferini açın və IP və əlaqə kodunu daxil edin.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>Windows məlumat transferi tərəfindən yükləyin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>Şəbəkə kodu möhkəm oldu, yeni kod üçün təmizləyin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>komputer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>Yerli IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>Təmizlə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>Kod %1-də möhkəm olacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>Lütfən ən qədim şəbəkə kodunu dəfələrlə daxil edin</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>Məlumat yedekləməsi yaradın</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>Fayl məlumatları</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>ölçü:0B</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>Yerləşmə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(Yedekləmə Diskını Seçin)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>Seçilmiş diskdə yaradıcı boşluq yoxdur, lütfən boşluq təmizləyin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>Yedekləmə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Ləğv et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>Ölçü:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>yerli disk</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 mövcuddur&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>Təkrar seç</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>Davam et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>Sizin və məqsəd cihazınız arasında tamamlanmamış transfer vəzifələrinin mövcudluğunu aşkar etdik.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>Son transferi davam etdirmək istəyirsinizmi?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>Transfer %1-də tamamlanacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>Yenidən cəhd edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>Şəbəkə Xətası</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>Transfer dayandı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>Şəbəkə kopru, transfer uğursuz oldu, lütfən şəbəkəni qoşun və yenidən cəhd edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>UOS-da yaradıcı boşluq yoxdur, lütfən minimum %1 GB boşluq təmizləyin və yenidən cəhd edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>UOS-da yeterli yer yoxdur, yeterli yer qeyd etməyin</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>Həcm</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>Transfer tamamlandığında məlumatlar istifadəçinin ev direktoriyasına yerləşdiriləcək</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>Təsdiq et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Ləğv et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>Transfer etmək üçün fail seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>Lütfən yedekləmək üçün fail(lar) seçin</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>Ağ bağlantısı kəsildi. Ağınızı yoxlayın</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>Yenidən cəhd edin</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>Yüklənir</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>Transfer öncə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>Məlumat transferi bir neçə vaxt tələb edir, batareyadan asılı olmayaraq köçün pozulmasına səbəb olmamalı, lütfən enerjiyə qoşulun.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>Digər tətbiqlər transfer sürətini azaldabilir. Daha mühüm təcrübə üçün digər tətbiqləri bağlayın.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>Transferin təhlükəsizliyi üçün təyinatlı ağdan istifadə edin.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>Təsdiq et</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>Bağlanmaq üçün hazırdır</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>Lütfən UOS-un IP adresini daxil edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>Lütfən UOS-da məlumat transferini açın və IP alın</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>Bağlanma kodu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>Lütfən UOS-da bağlanma kodunu daxil edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>bağlanma...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>Bağlanma uğursuz oldu, daxil etdiyinizə əsasən yoxlayın</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>Transfer təkamilən tamamlandı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>Transfer tamamlandı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>Bəzi məlumatların köçürülməsi uğursuz oldu, əlilə köçürmək üçün UOS-a gedin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>Seçilmiş:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>Seçilmiş:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>Düzəlt</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>Fayl</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>Tətbiq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>Konfiqurasiya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>Köçürülmək üçün məlumat seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>Yedekləmək üçün məzmunu seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>Köçürməni başlayın</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>Növbəti</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>Profillər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>Yanlış və ya mövcud olmayan profil</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>Mənim Pəncərəm</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>Köçürmə tamamlandı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>Tarayıcı Sənədləri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>Tarayıcı Sənədi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>davamlı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>Davamlı</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>Köçürmə uğursuz</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>Format xətası</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>Təyinat uğursuz oldu, konfiqurasiya əlilə daxil edilə bilər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>Tətbiqin quraşdırılması uğursuz oldu, tətbiq mağazasına gedin və quraşdırın</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>Köçürmə Tamamlandı</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>Şəkillər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>Dokumentlər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>Yükləmələr</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>Seç:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>yerli disk</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>UOS məlumat transferi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>UOS transfer aləti, bir klik ilə sənədlərin, şəxsi məlumatların və tətbiqlərin UOS-a köçürülməsini və səsərək sisteminizi dəyişməyə kömək edir.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>Növbəti</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>Köçürülür</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>Köçürülür...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>Hesablanır...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>Prosesləri göstər</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>Prosesləri gizlə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>%1 dəqiqə ərzində köçürmə tamamlanacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>Köçürülür</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>%1 saniyə ərzində köçürmə tamamlanacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>Köçürmə tamamlanacaq --</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>Açılır</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>Açılır</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>Faylı buraya çəkin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>Faylı yüklə</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>Yalnız .zip dəstəklənir, lütfən</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>təkrar seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>zip faylı seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>ZIP faylı (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>Məlumat transfer faylı seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>Fayl xətası, transfer edilməyə bilməz, lütfən təkrar seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>Növbəti</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>Yenidən cəhd edin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>Fayl pozitivdir və köçürülməyə bənzəmir. Onu yedekləmə faylı ilə əvəz edin.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>UOS-da yeterli yer yoxdur. Azad yer kimi %1G və ya daha çox yer qeyd etməyiniz və yenidən cəhd edin.</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>Hesablanır</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>Köçürmə gözlənilir...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>Lütfən Windows-da köçürmək üçün məlumat seçin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>Ləğv et</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>Bağla</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>Bu əməliyyat göndərmə progresini siləcək, davam etmək istəyirsinizmi?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>Bu əməliyyat geri qaytarılmaz</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>Yedekləmə uğurludur</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>Təbrik edirik, Sizin məlumatlarınız uğurla yedək edildi.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>Görünüşə Bax</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>Yedekləmə səbəbən başlamadı</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>Paketləmə %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Köçürmə %1 dəqiqədə tamamlanacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Köçürmə %1 saniyədə tamamlanacaq</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>Yedekləmə Faylı Yaratılır...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 Fayl sıxılmaq səbəbən başlamadı&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>Yedekləmə faylı tamamlandı</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>UOS məlumatı köçürmə</translation>
    </message>
</context>
</TS>